@@ -17,6 +17,8 @@ else
   end
 end
 
+have_func('mysql_ssl_set')
+
 if have_header('mysql.h') then
   src = "#include <errmsg.h>\n#include <mysqld_error.h>\n"
 elsif have_header('mysql/mysql.h') then
@@ -55,7 +57,7 @@ error_syms.uniq!
 newf = File::open('mysql.c', 'w')
 IO::foreach('mysql.c.in') do |l|
   newf.puts l
-  if l =~ /\/\* MysqlError constant \*\// then
+  if l =~ /\/\* Mysql::Error constant \*\// then
     error_syms.each do |s|
       newf.puts "    rb_define_const(eMysql, \"#{s}\", INT2NUM(#{s}));"
     end
